@@ -5,7 +5,7 @@ cache_config = None
 
 try:
     from paste.registry import StackedObjectProxy
-    cache_manager = StackedObjectProxy()
+    cache_manager = StackedObjectProxy(name="Cache Manager")
 except:
     pass
 
@@ -16,7 +16,9 @@ class Cache:
     or processes.  (the containment API it talks to, is).
     
     """
-    def __init__(self, cache_info={}, type=None, container_class=None , debug_file=None, **params):
+    def __init__(self, cache_info=None, type=None, container_class=None , debug_file=None, **params):
+        if cache_info is None:
+            cache_info = {}
         self.params = CacheArgs()
         self.params.set_params(**params)
         self.type = type
@@ -107,8 +109,10 @@ class CacheManager(object):
         return Cache(cache_info, **cparams)
 
 class CacheMiddleware(object):
-    def __init__(self, app, global_conf={}, **params):
+    def __init__(self, app, global_conf=None, **params):
         self.app = app
+        if global_conf is None:
+            global_conf = {}
         cache_params = CacheArgs(**global_conf)
         cache_params.set_prefix_params(**params)
         self.cache_manager = CacheManager(**cache_params.params)
